@@ -9,7 +9,7 @@ from django.contrib.auth.decorators import login_required
 from django.core.cache import cache
 from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
 from django.db import IntegrityError
-from django.db.models import Q, ProtectedError
+from django.db.models import Q, ProtectedError, prefetch_related_objects
 from django.http import HttpResponse, HttpResponseRedirect
 from django.shortcuts import get_object_or_404
 from django.template.response import TemplateResponse
@@ -44,13 +44,12 @@ def home(request):
     if not organization:
         return HttpResponseRedirect(reverse('bom:organization-create'))
 
-    query = request.POST.get('q', '')
+    query = request.GET.get('q', '')
     title = f'{organization.name}\'s'
-
-    if request.method == 'POST':
-        part_class_selection_form = PartClassSelectionForm(request.POST, organization=organization)
-        if 'actions' in request.POST and 'part-action' in request.POST:
-            action = request.POST.get('part-action')
+    if request.method == 'GET':
+        part_class_selection_form = PartClassSelectionForm(request.GET, organization=organization)
+        if 'actions' in request.POST and 'part-action' in request.GET:
+            action = request.GET.get('part-action')
             if action == 'Delete':
                 for part_id in request.POST.getlist('actions'):
                     try:
@@ -78,7 +77,7 @@ def home(request):
     if part_class:
         parts = Part.objects.filter(Q(organization=organization) & Q(number_class__code=part_class.code))
     else:
-        parts = Part.objects.filter(Q(organization=organization))
+        parts = Part.objects.filter(organization=organization)
 
     part_ids = list(parts.values_list('id', flat=True))
 
@@ -92,13 +91,15 @@ def home(request):
     part_list = ','.join(map(str, part_ids)) if len(part_ids) > 0 else "NULL"
     q = part_rev_query.format(part_list)
     part_revs = PartRevision.objects.raw(q)
-    manufacturer_part = ManufacturerPart.objects.filter(part__in=parts)
+    prefetch_related_objects(part_revs, 'part')
+    manufacturer_parts = ManufacturerPart.objects.filter(part__in=parts)
 
     autocomplete_dict = {}
-    for part in part_revs:
-        autocomplete_dict.update({part.searchable_synopsis.replace('"', ''): None})
+    for pr in part_revs:
+        autocomplete_dict.update({pr.searchable_synopsis.replace('"', ''): None})
+        autocomplete_dict.update({pr.part.full_part_number(): None})
 
-    for mpn in manufacturer_part:
+    for mpn in manufacturer_parts:
         if mpn.manufacturer_part_number:
             autocomplete_dict.update({mpn.manufacturer_part_number.replace('"', ''): None})
         if mpn.manufacturer is not None and mpn.manufacturer.name:
@@ -125,11 +126,12 @@ def home(request):
         number_variation = None
 
         # Scan for search terms that might represent a complete or partial part number
-        for search_term in search_terms:
-            try:
-                (number_class, number_item, number_variation) = Part.parse_partial_part_number(search_term, organization)
-            except AttributeError:
-                pass
+        if organization.number_scheme == constants.NUMBER_SCHEME_SEMI_INTELLIGENT:
+            for search_term in search_terms:
+                try:
+                    (number_class, number_item, number_variation) = Part.parse_partial_part_number(search_term, organization, validate=False)
+                except AttributeError:
+                    pass
 
         # Query searchable_synopsis by OR'ing search terms
         part_synopsis_ids = PartRevision.objects.filter(reduce(operator.or_, (Q(searchable_synopsis__icontains=term) for term in search_terms))).values_list("part", flat=True)
@@ -153,6 +155,7 @@ def home(request):
                 q_primary_mfg)
         else:
             parts = parts.filter(
+                Q(number_item__in=search_terms) |
                 Q(id__in=part_synopsis_ids) |
                 q_primary_mpn |
                 q_primary_mfg)
@@ -162,7 +165,7 @@ def home(request):
         q = part_rev_query.format(part_list)
         part_revs = PartRevision.objects.raw(q)
 
-    if 'download' in request.POST:
+    if 'download' in request.GET:
         response = HttpResponse(content_type='text/csv')
         response['Content-Disposition'] = 'attachment; filename="indabom_parts_search.csv"'
         csv_headers = organization.part_list_csv_headers()
@@ -206,6 +209,7 @@ def home(request):
         part_revs = paginator.page(1)
     except EmptyPage:
         part_revs = paginator.page(paginator.num_pages)
+
     return TemplateResponse(request, 'bom/dashboard.html', locals())
 
 
